@@ -1,24 +1,34 @@
-# Copyright (c) 2008 by Ricardo Signes. All rights reserved.
-# Licensed under terms of Perl itself (the "License").
-# You may not use this file except in compliance with the License.
-# A copy of the License was distributed with this file or you may obtain a 
-# copy of the License from http://dev.perl.org/licenses/
-
-package Metabase;
+# 
+# This file is part of Metabase
+# 
+# This software is Copyright (c) 2010 by David Golden.
+# 
+# This is free software, licensed under:
+# 
+#   The Apache License, Version 2.0, January 2004
+# 
 use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.005';
-$VERSION = eval $VERSION;
+package Metabase;
+our $VERSION = '0.006';
+# ABSTRACT: A database framework and API for resource metadata
+
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-Metabase - a database framework and API for resource metadata
+Metabase - A database framework and API for resource metadata
+
+=head1 VERSION
+
+version 0.006
 
 =head1 DESCRIPTION
 
@@ -110,25 +120,22 @@ L<http://rt.cpan.org/Dist/Display.html?Queue=Metabase>
 When submitting a bug or request, please include a test-file or a patch to an
 existing test-file that illustrates the bug or desired feature.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-  David A. Golden (DAGOLDEN)
-  Ricardo J. B. Signes (RJBS)
+  David Golden <dagolden@cpan.org>
+  Ricardo Signes <rjbs@cpan.org>
+  Leon Brocard <acme@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
- Portions Copyright (c) 2008-2010 by David A. Golden
- Portions Copyright (c) 2008 by Ricardo J. B. Signes
+This software is Copyright (c) 2010 by David Golden.
 
-Licensed under the same terms as Perl itself (the "License").
-You may not use this file except in compliance with the License.
-A copy of the License was distributed with this file or you may obtain a 
-copy of the License from http://dev.perl.org/licenses/
+This is free software, licensed under:
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+  The Apache License, Version 2.0, January 2004
 
 =cut
+
+
+__END__
+
