@@ -1,4 +1,20 @@
+# 
+# This file is part of Metabase
+# 
+# This software is Copyright (c) 2010 by David Golden.
+# 
+# This is free software, licensed under:
+# 
+#   The Apache License, Version 2.0, January 2004
+# 
+use 5.006;
+use strict;
+use warnings;
+
 package Metabase::Gateway;
+our $VERSION = '0.006';
+# ABSTRACT: Manage Metabase fact submission
+
 use Moose::Role;
 
 use Metabase::Fact;
@@ -257,7 +273,7 @@ sub enqueue {
 
 1;
 
-__END__
+
 
 =pod
 
@@ -265,6 +281,10 @@ __END__
 
 Metabase::Gateway - Manage Metabase fact submission
 
+=head1 VERSION
+
+version 0.006
+
 =head1 SYNOPSIS
 
   my $mg = Metabase::Gateway->new(
@@ -361,35 +381,23 @@ L<http://rt.cpan.org/Dist/Display.html?Queue=Metabase>
 When submitting a bug or request, please include a test-file or a patch to an
 existing test-file that illustrates the bug or desired feature.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-=over
-
-=item *
-
-David A. Golden (DAGOLDEN)
-
-=item *
-
-Ricardo J. B. Signes (RJBS)
-
-=back
+  David Golden <dagolden@cpan.org>
+  Ricardo Signes <rjbs@cpan.org>
+  Leon Brocard <acme@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
- Portions Copyright (c) 2008-2010 by David A. Golden
- Portions Copyright (c) 2008-2009 by Ricardo J. B. Signes
+This software is Copyright (c) 2010 by David Golden.
 
-Licensed under terms of Perl itself (the "License").
-You may not use this file except in compliance with the License.
-A copy of the License was distributed with this file or you may obtain a
-copy of the License from http://dev.perl.org/licenses/
+This is free software, licensed under:
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+  The Apache License, Version 2.0, January 2004
 
 =cut
 
+
+__END__
+
+
