@@ -1,14 +1,21 @@
-# Copyright (c) 2008 by Ricardo Signes. All rights reserved.
-# Licensed under terms of Perl itself (the "License").
-# You may not use this file except in compliance with the License.
-# A copy of the License was distributed with this file or you may obtain a 
-# copy of the License from http://dev.perl.org/licenses/
+# 
+# This file is part of Metabase
+# 
+# This software is Copyright (c) 2010 by David Golden.
+# 
+# This is free software, licensed under:
+# 
+#   The Apache License, Version 2.0, January 2004
+# 
+use 5.006;
+use strict;
+use warnings;
 
 package Metabase::Index;
-use Moose::Role;
+our $VERSION = '0.006';
+# ABSTRACT: Interface for Metabase indexing
 
-our $VERSION = '0.005';
-$VERSION = eval $VERSION;
+use Moose::Role;
 
 requires 'add';
 requires 'search';
@@ -44,7 +51,7 @@ sub clone_metadata {
 
 1;
 
-__END__
+
 
 =pod
 
@@ -52,6 +59,10 @@ __END__
 
 Metabase::Index - Interface for Metabase indexing
 
+=head1 VERSION
+
+version 0.006
+
 =head1 SYNOPSIS
 
   package Metabase::Index::Bar;
@@ -72,12 +83,13 @@ Metabase::Index - Interface for Metabase indexing
     return \@matches;
   }
 
-
 =head1 DESCRIPTION
 
 This describes the interface for indexing and searching facts.  Implementations
 must provide the C<add> and C<search> methods.
 
+=for Pod::Coverage clone_metadata
+
 =head1 USAGE
 
 =head2 C<exists>
@@ -104,7 +116,7 @@ Keys should be keys from core, content, or resource metadata.  E.g.
   core.type
   core.resource
   content.somefield
-  
+
 =head1 BUGS
 
 Please report any bugs or feature using the CPAN Request Tracker.  
@@ -114,34 +126,22 @@ L<http://rt.cpan.org/Dist/Display.html?Queue=Metabase>
 When submitting a bug or request, please include a test-file or a patch to an
 existing test-file that illustrates the bug or desired feature.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-=over 
-
-=item *
-
-David A. Golden (DAGOLDEN)
-
-=item *
-
-Ricardo J. B. Signes (RJBS)
-
-=back
+  David Golden <dagolden@cpan.org>
+  Ricardo Signes <rjbs@cpan.org>
+  Leon Brocard <acme@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
- Portions Copyright (c) 2008-2009 by David A. Golden
- Portions Copyright (c) 2008-2009 by Ricardo J. B. Signes
+This software is Copyright (c) 2010 by David Golden.
 
-Licensed under terms of Perl itself (the "License").
-You may not use this file except in compliance with the License.
-A copy of the License was distributed with this file or you may obtain a 
-copy of the License from http://dev.perl.org/licenses/
+This is free software, licensed under:
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+  The Apache License, Version 2.0, January 2004
 
 =cut
+
+
+__END__
+
